#[non_exhaustive]pub enum ResourceError {
RelativeReference,
InvalidCharacters,
InvalidPercentEncoding,
InvalidHttpUri(InvalidUri),
MissingHttpAuthority,
}Expand description
Errors that can occur while parsing a WebFinger resource URI.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
RelativeReference
The resource is a relative reference instead of an absolute URI.
InvalidCharacters
The resource contains raw text outside the URI character set.
Resource URI text must be ASCII and every byte must be allowed by RFC 3986 as an
unreserved, reserved, or percent-escape marker byte. Characters outside that set, such
as {, |, ^, and non-ASCII code points, must be percent-encoded before parsing.
InvalidPercentEncoding
The resource contains a malformed percent escape.
InvalidHttpUri(InvalidUri)
The resource is an invalid HTTP or HTTPS URI.
MissingHttpAuthority
The resource is an HTTP or HTTPS URI without an authority.